package com.chinaitop.depot.intelligent.priceApproval.controller;


import com.chinaitop.depot.intelligent.common.ResponseEntity;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsOutConfirmDiffPriceItem;
import com.chinaitop.depot.intelligent.priceApproval.model.*;
import com.chinaitop.depot.intelligent.priceApproval.service.BusinessFsSaleRevenueService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 * 财务监管-销售收入上缴 前端控制器
 * </p>
 *
 * @author root
 * @since 2024-07-24
 */
@RestController
@RequestMapping("/business-fs-sale-revenue")
@Api(tags = "销售收入上缴")
public class BusinessFsSaleRevenueController {
    @Resource
    private BusinessFsSaleRevenueService saleRevenueService;

    @GetMapping("/getContractInfo/{orgId}")
    @ApiOperation(value = "合同编号下拉", notes = "包含合同其它信息")
    public ResponseEntity<List<BusinessContract>> getContractInfo(@PathVariable("orgId") Integer orgId) {
        return ResponseEntity.ok(saleRevenueService.getContractInfo(orgId));
    }

    @GetMapping("/getContractInfoById/{id}")
    @ApiOperation(value = "合同信息", notes = "合同编号下拉id")
    public ResponseEntity<List<BusinessContractDetail>> getContractInfoList(@PathVariable("id") Integer id) {
        return ResponseEntity.ok(saleRevenueService.getContractInfoList(id));
    }

    @GetMapping("/getConsistenceAccountInfo/{orgId}/{basicStorehouseId}/{warehouseId}")
    @ApiOperation(value = "质检损益信息", notes = "质检损益信息")
    public ResponseEntity<List<BusinessFsSaleRevenueInspectionLoss>> getQualityInfo(@PathVariable("orgId") Integer orgId,
                                                                                    @PathVariable("basicStorehouseId") Integer basicStorehouseId,
                                                                                    @PathVariable("warehouseId") Integer warehouseId) {
        return ResponseEntity.ok(saleRevenueService.getQualityInfo(orgId, basicStorehouseId, warehouseId));
    }

    @GetMapping("/getConsistenceAccountInfo/{contractNumber}")
    @ApiOperation(value = "三账一致性-会计账", notes = "会计账")
    public ResponseEntity<List<BusinessFsSaleRevenueThreeConsistence>> getConsistenceAccountInfo(@PathVariable("contractNumber") String contractNumber) {
        return ResponseEntity.ok(saleRevenueService.getConsistenceAccountInfo(contractNumber));
    }

    @GetMapping("/getOutStorageInfo/{contractNumber}")
    @ApiOperation(value = "三账一致性-实际出库情况", notes = "实际出库情况")
    public ResponseEntity<List<BusinessFsSaleRevenueThreeConsistence>> getOutStorageInfo(@PathVariable("contractNumber") String contractNumber) {
        return ResponseEntity.ok(saleRevenueService.getOutStorageInfo(contractNumber));
    }

    @GetMapping("/getOutStorageDetailed/{contractNumber}")
    @ApiOperation(value = "三账一致性-出库明细", notes = "出库明细")
    public ResponseEntity<List<DataCPZ>> getOutStorageDetailed(@PathVariable("contractNumber") String contractNumber) {
        return ResponseEntity.ok(saleRevenueService.getOutStorageDetailed(contractNumber));
    }

    @GetMapping("/getSettlementInfo/{contractNumber}")
    @ApiOperation(value = "结算信息", notes = "结算信息")
    public ResponseEntity<List<BusinessFsSaleRevenueSettle>> getSettlementInfo(@PathVariable("contractNumber") String contractNumber) {
        return ResponseEntity.ok(saleRevenueService.getSettlementInfo(contractNumber));
    }

    @GetMapping("/getDiffPriceInfo/{contractNumber}")
    @ApiOperation(value = "差价上缴", notes = "差价上缴")
    public ResponseEntity<List<BusinessFsSaleRevenueDiffPrice>> getDiffPriceInfo(@PathVariable("contractNumber") String contractNumber) {
        return ResponseEntity.ok(saleRevenueService.getDiffPriceInfo(contractNumber));
    }

    @GetMapping("/getCardInfo/{orgId}/{basicStorehouseId}/{warehouseId}")
    @ApiOperation(value = "原核定入库价格", notes = "原核定入库价格")
    public ResponseEntity<List<BusinessFsSaleRevenueApprovalPrice>> getCardInfo(@PathVariable("orgId") Integer orgId,
                                                                     @PathVariable("basicStorehouseId") Integer basicStorehouseId,
                                                                     @PathVariable("warehouseId") Integer warehouseId) {
        return ResponseEntity.ok(saleRevenueService.getCardInfo(orgId, basicStorehouseId, warehouseId));
    }

    @PostMapping("/save")
    @ApiOperation(value = "销售收入上缴新增", notes = "新增")
    public ResponseEntity save(@Validated @RequestBody BusinessFsSaleRevenue param) {
        saleRevenueService.saveData(param);
        return ResponseEntity.ok();
    }

}
